@@ -98,13 +98,39 @@ class PKMClient(object):
         self.key = USER_KEY
         return True
 
+    def now(self):
+        return datetime.now().strftime("%Y%m%d_%H%M%S")
+
+    def update_invocation(self, project_id, invocationId, status, resultsToAdd):
+        invocationUpdate = dict()
+        invocationUpdate["invocationID"] = invocationId
+
+        if status:
+            invocationUpdate["invocationStatus"] = "COMPLETED"
+        else:
+            invocationUpdate["invocationStatus"] = "FAILED"
+            invocationUpdate["invocationResults"] = dict(path="FAILED", type="message")
+
+        invocationUpdate["invocationResults"] = resultsToAdd
+
+        invocationUpdate["timestampCompleted"] = self.now()
+
+        getSt, getTx = self.call(
+            method='GET',
+            path=f"/invocations/{project_id}/{invocationUpdate['invocationID']}")
+
+        inv = json.loads(getTx)
+        inv.update(invocationUpdate)
+        return self.call(method='PUT', path='/invocations/'+project_id,
+                         payload=json.dumps([inv]))
+
 
 class Log(object):
 
     def __init__(self, pkm: PKMClient, project: str,
                  tool: str, status: str = "",
                  details: dict = {}, nature: str = "Execution report",
-                 max_msg_len = 80):
+                 max_msg_len=80, invocation_id=None):
         self.pkm = pkm
         self.project = project
         # tool name/tag
@@ -124,11 +150,17 @@ class Log(object):
         self.errors = []
         self.status = True
         self.details = {}
+        self.invocation_id = invocation_id
 
     def __del__(self):
         status, result = self.pkm.call(method='POST',
                                        path=f"log/{self.project}",
                                        payload=[self.json()])
+        if self.invocation_id is not None:
+            newLogID = json.loads(result)[0]
+            self.pkm.update_invocation(
+                self.project, self.invocation_id, status,
+                dict(path=f"log/{self.project}"+str(newLogID), type="log"))
         if status != 0:
             print(f"Logging {self.json()} failed with {status}: {result}",
                   file=sys.stderr)
